@@ -1,7 +1,9 @@
 """Views of the ``cmsplugin_blog_categories`` app."""
 from django.views.generic import ListView
+from django.utils import timezone
 
-from cmsplugin_blog_categories.models import Category
+from cmsplugin_blog.models import Entry
+from cmsplugin_blog_categories.models import EntryCategory, Category
 
 
 class CategoryListView(ListView):
@@ -19,6 +21,4 @@ class CategoryListView(ListView):
         return ctx
 
     def get_queryset(self):
-        return [category.entry for category
-                in self.category.entry_categories.all()
-                if category.entry.is_published]
+        return self.category.get_entries()
